@@ -72,11 +72,27 @@ def __import_file(filename):
 
         else:
 
-            copyfile(file_position, file_path)
+            try:
+
+                copyfile(file_position, file_path)
+
+            except:
+
+                warning_message = "\n\n<----------------- !WARNING! ------------------->\n"
+                warning_message += "Unable to copy the file to the desired location!\n\n"
+
+            else:
+
+                warning_message = "\n\n<----------------- !SUCCESS! ------------------->\n"
+                warning_message += "File successfully copied to the desired location!\n\n"
+
+            warning_message += "file name:\t\t\t" + filename + "\n"
+            warning_message += "file position:\t" + file_path + "\n\n"
+
+            warnings.warn(warning_message)
 
 
 def __retrieve_file(filename, file_position):
-
     token = costants.GITHUB_CONGIF["token"]
     base_repo = costants.GITHUB_CONGIF["repo"]
     base_path = costants.GITHUB_CONGIF["path"]
@@ -103,4 +119,4 @@ def __retrieve_file(filename, file_position):
         warning_message += "status_code:\t\t" + str(r.status_code) + "\n"
         warning_message += "url:\t\t\t" + url + "\n\n"
 
-        raise RuntimeError(warning_message)
\ No newline at end of file
+        raise RuntimeError(warning_message)
