@@ -28,12 +28,19 @@ class MyTestCase(unittest.TestCase):
 
         import EEETools
 
-        EEETools.paste_components_documentation()
-        EEETools.paste_user_manual()
+        #EEETools.paste_components_documentation()
+        #EEETools.paste_user_manual()
         EEETools.paste_default_excel_file()
 
         self.assertTrue(True)
 
+    def test_main_modules_calculation(self):
+
+        import EEETools
+        EEETools.calculate()
+
+        self.assertTrue(True)
+
 
 if __name__ == '__main__':
     unittest.main()
